@@ -8,9 +8,9 @@
   (char *)((struct ucontext *)scp )->uc_mcontext.sc_traparg_a0
 
 #define SGC
-#include <asm/system.h>
+#define PAL_imb		134
+#define imb() \
+__asm__ __volatile__ ("call_pal %0 #imb" : : "i" (PAL_imb) : "memory")
 #define CLEAR_CACHE imb()
 #define SPECIAL_BFD_INCLUDE "sfaslbfd_alpha.c"
 #define NOINTDIV
-#undef LIBC_EXT
-#define LIBC_EXT ".6.1" /*FIXME*/
