@@ -275,7 +275,7 @@ EXTER object sSdefmacroA;
 object macro_expand();
 
 /*  main.c  */
-EXTER char* system_directory;
+EXTER char system_directory[512];
 EXTER int ARGC;
 EXTER char **ARGV;
 void error();
@@ -578,7 +578,7 @@ object getf();
 object get();
 object putf();
 object putprop();
-object sputprop();
+object fSsputprop();
 object remprop();
 object gensym();		/*  to be deleted  */
 
