@@ -3,7 +3,7 @@
 #define ADDITIONAL_FEATURES ADD_FEATURE("SPARC")
 
 #define	SPARC
-#define SGC
+/* #define SGC */
 
 #define PTR_ALIGN 8
 
