@@ -35,7 +35,6 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 #include "num_include.h"
 
 object plus_half, minus_half;
-extern void zero_divisor(void);
 #ifdef CONVEX
 #define VAX
 #endif
@@ -134,7 +133,30 @@ int gcl_isnormal_float(float f)
 	LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL
 */
 #endif
-static void
+
+
+DEFUN_NEW("ISFINITE",object,fSisfinite,SI,1,1,NONE,OO,OO,OO,OO,(object x),"") {
+
+  switch (type_of(x)) {
+  case t_longfloat:
+    return lf(x)==0.0 || ISFINITE(lf(x)) ? Ct : Cnil;
+    break;
+  case t_shortfloat:
+    return sf(x)==0.0 || ISFINITE(sf(x)) ? Ct : Cnil;
+    break;
+  default:
+    return Cnil;
+    break;
+  }
+
+  return Cnil;
+
+}
+
+
+
+
+void
 integer_decode_double(double d, int *hp, int *lp, int *ep, int *sp)
 {
 	int h, l;
@@ -544,9 +566,7 @@ TWO_ARG:
 		too_many_arguments();
 	x = vs_base[0];
 	y = vs_base[1];
-        if ( number_zerop ( y ) == TRUE ) {
-            zero_divisor();
-        }
+        if ( number_zerop ( y ) == TRUE ) DIVISION_BY_ZERO(sLfloor,list(2,x,y));
 	if ((type_of(x) == t_fixnum || type_of(x) == t_bignum) &&
 	    (type_of(y) == t_fixnum || type_of(y) == t_bignum)) {
 		vs_base = vs_top;
@@ -670,9 +690,7 @@ TWO_ARG:
 		too_many_arguments();
 	x = vs_base[0];
 	y = vs_base[1];
-        if ( number_zerop ( y ) == TRUE ) {
-            zero_divisor();
-        }
+        if ( number_zerop ( y ) == TRUE ) DIVISION_BY_ZERO(sLceiling,list(2,x,y));
 	if ((type_of(x) == t_fixnum || type_of(x) == t_bignum) &&
 	    (type_of(y) == t_fixnum || type_of(y) == t_bignum)) {
 		vs_base = vs_top;
@@ -734,9 +752,78 @@ TWO_ARG:
 	}
 }
 
+static void
+truncate_2(object x,object y) {
+
+  enum type tx=type_of(x),ty=type_of(y);
+  object q,q1;
+
+  if ((tx==t_fixnum || tx==t_bignum) &&
+      (ty==t_fixnum || ty==t_bignum)) {
+    
+    fixnum fx=fix(x),fy=fix(y),t;
+    
+    if (ty==t_fixnum && !fy) DIVISION_BY_ZERO(sLtruncate,list(2,x,y));
+    
+    if (tx==t_fixnum && fx!=MOST_NEGATIVE_FIX) {
+      
+      if (ty==t_fixnum) {
+	vs_base[0]=make_fixnum((t=fx/fy));
+	vs_base[1]=make_fixnum(fx-t*fy);
+	return;
+      }
+      vs_base[0]=small_fixnum(0);
+      vs_base[1]=x;
+      return;
+    }
+    if (ty==t_fixnum && fy>0)
+      integer_quotient_remainder_1_ui(x, fy, vs_base, vs_base+1);
+    else
+      integer_quotient_remainder_1(x, y, vs_base, vs_base+1);
+    return;
+  }
+  
+  
+  if ( number_zerop ( y ) == TRUE ) DIVISION_BY_ZERO(sLtruncate,list(2,x,y));
+  if ((type_of(x) == t_fixnum || type_of(x) == t_bignum) &&
+      (type_of(y) == t_fixnum || type_of(y) == t_bignum)) {
+    integer_quotient_remainder_1(x, y, &vs_base[0], &vs_base[1]);
+    return;
+  }
+  check_type_or_rational_float(&vs_base[0]);
+  check_type_or_rational_float(&vs_base[1]);
+  q = number_divide(x, y);
+  vs_push(q);
+  switch (type_of(q)) {
+  case t_fixnum:
+  case t_bignum:
+    vs_base = vs_top;
+    vs_push(q);
+    vs_push(small_fixnum(0));
+    break;
+    
+  case t_ratio:
+    q1 = integer_divide1(q->rat.rat_num, q->rat.rat_den);
+    vs_base = vs_top;
+    vs_push(q1);
+    vs_push(num_remainder(x, y, q1));
+    return;
+    
+  case t_shortfloat:
+  case t_longfloat:
+    q1 = double_to_integer(number_to_double(q));
+    vs_base = vs_top;
+    vs_push(q1);
+    vs_push(num_remainder(x, y, q1));
+    return;
+  default:
+    break;
+  }
+}
+
 LFD(Ltruncate)(void)
 {
-	object x, y, q, q1;
+	object x, y, q1;
 	int n;
 
 	n = vs_top - vs_base;
@@ -782,43 +869,7 @@ TWO_ARG:
 		too_many_arguments();
 	x = vs_base[0];
 	y = vs_base[1];
-        if ( number_zerop ( y ) == TRUE ) {
-            zero_divisor();
-        }
-	if ((type_of(x) == t_fixnum || type_of(x) == t_bignum) &&
-	    (type_of(y) == t_fixnum || type_of(y) == t_bignum)) {
-		integer_quotient_remainder_1(x, y, &vs_base[0], &vs_base[1]);
-		return;
-	}
-	check_type_or_rational_float(&vs_base[0]);
-	check_type_or_rational_float(&vs_base[1]);
-	q = number_divide(x, y);
-	vs_push(q);
-	switch (type_of(q)) {
-	case t_fixnum:
-	case t_bignum:
-		vs_base = vs_top;
-		vs_push(q);
-		vs_push(small_fixnum(0));
-		break;
-	
-	case t_ratio:
-		q1 = integer_divide1(q->rat.rat_num, q->rat.rat_den);
-		vs_base = vs_top;
-		vs_push(q1);
-		vs_push(num_remainder(x, y, q1));
-		return;
-
-	case t_shortfloat:
-	case t_longfloat:
-		q1 = double_to_integer(number_to_double(q));
-		vs_base = vs_top;
-		vs_push(q1);
-		vs_push(num_remainder(x, y, q1));
-		return;
-	default:
-	  break;
-	}
+	truncate_2(x,y);
 }
 
 LFD(Lround)(void)
@@ -1163,29 +1214,18 @@ LFD(Lfloat_precision)(void)
 #endif
 }
 
-LFD(Linteger_decode_float)(void)
-{
-	object x;
-	int h, l, e, s;
+DEFUN_NEW("INTEGER-DECODE-FLOAT",object,fLinteger_decode_float,LISP,1,1,NONE,OO,OO,OO,OO,(object x),"") {
+
+  int h,l,e,s;
+  
+  check_type_float(&x);
+  h=0;
+  if (type_of(x) == t_longfloat)
+    integer_decode_double(lf(x), &h, &l, &e, &s);
+  else
+    integer_decode_float((double)(sf(x)), &l, &e, &s);
+  RETURN3((h || l<0) ? bignum2(h, l) : make_fixnum(l),make_fixnum(e),make_fixnum(s));
 
-	check_arg(1);
-	check_type_float(&vs_base[0]);
-	x = vs_base[0];
-	vs_base = vs_top;
-	if (type_of(x) == t_longfloat) {
-		integer_decode_double(lf(x), &h, &l, &e, &s);
-		if (h != 0 || l<0)
-			vs_push(bignum2(h, l));
-		else
-			vs_push(make_fixnum(l));
-		vs_push(make_fixnum(e));
-		vs_push(make_fixnum(s));
-	} else {
-		integer_decode_float((double)(sf(x)), &h, &e, &s);
-		vs_push(make_fixnum(h));
-		vs_push(make_fixnum(e));
-		vs_push(make_fixnum(s));
-	}
 }
 
 LFD(Lcomplex)(void)
@@ -1419,6 +1459,10 @@ gcl_init_num_co(void)
 	/* Maybe check for "right" answer here */
 #endif
 
+	make_si_constant("+INF",make_longfloat(INFINITY));
+	make_si_constant("-INF",make_longfloat(-INFINITY));
+	make_si_constant("NAN",make_longfloat(NAN));
+
 	make_constant("MOST-POSITIVE-SHORT-FLOAT",
 		      make_shortfloat(biggest_float));
 	make_constant("LEAST-POSITIVE-SHORT-FLOAT",
@@ -1512,7 +1556,7 @@ gcl_init_num_co(void)
 	make_function("FLOAT-SIGN", Lfloat_sign);
 	make_function("FLOAT-DIGITS", Lfloat_digits);
 	make_function("FLOAT-PRECISION", Lfloat_precision);
-	make_function("INTEGER-DECODE-FLOAT", Linteger_decode_float);
+/* 	make_function("INTEGER-DECODE-FLOAT", Linteger_decode_float); */
 	make_function("COMPLEX", Lcomplex);
 	make_function("REALPART", Lrealpart);
 	make_function("IMAGPART", Limagpart);
